"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguageDetector = void 0;
class LanguageDetector {
    constructor() {
        this.languageMap = {
            // JavaScript/TypeScript
            'javascript': 'javascript',
            'typescript': 'typescript',
            'typescriptreact': 'tsx',
            'javascriptreact': 'jsx',
            'json': 'json',
            'jsonc': 'json',
            // Web
            'html': 'html',
            'css': 'css',
            'scss': 'scss',
            'sass': 'sass',
            'less': 'less',
            // Python
            'python': 'python',
            // Go
            'go': 'go',
            // Rust
            'rust': 'rust',
            // C/C++
            'c': 'c',
            'cpp': 'cpp',
            'csharp': 'csharp',
            // Java
            'java': 'java',
            // PHP
            'php': 'php',
            // Ruby
            'ruby': 'ruby',
            // Shell/Bash
            'shellscript': 'bash',
            'powershell': 'powershell',
            'bat': 'batch',
            // Config files
            'yaml': 'yaml',
            'yml': 'yaml',
            'xml': 'xml',
            'toml': 'toml',
            'ini': 'ini',
            // Docker
            'dockerfile': 'dockerfile',
            // SQL
            'sql': 'sql',
            // Markdown
            'markdown': 'markdown',
            // Default fallback
            'plaintext': 'plaintext'
        };
    }
    detectFromDocument(document) {
        // First try to detect from VS Code language ID
        const vscodeLanguage = document.languageId;
        if (this.languageMap[vscodeLanguage]) {
            return this.languageMap[vscodeLanguage];
        }
        // Try to detect from file extension
        const fileName = document.fileName;
        const extension = fileName.split('.').pop()?.toLowerCase() || '';
        const extensionMap = {
            'js': 'javascript',
            'ts': 'typescript',
            'jsx': 'jsx',
            'tsx': 'tsx',
            'py': 'python',
            'go': 'go',
            'rs': 'rust',
            'c': 'c',
            'cpp': 'cpp',
            'cc': 'cpp',
            'cxx': 'cpp',
            'cs': 'csharp',
            'java': 'java',
            'php': 'php',
            'rb': 'ruby',
            'sh': 'bash',
            'bash': 'bash',
            'zsh': 'bash',
            'ps1': 'powershell',
            'bat': 'batch',
            'cmd': 'batch',
            'yml': 'yaml',
            'yaml': 'yaml',
            'xml': 'xml',
            'html': 'html',
            'htm': 'html',
            'css': 'css',
            'scss': 'scss',
            'sass': 'sass',
            'less': 'less',
            'json': 'json',
            'toml': 'toml',
            'ini': 'ini',
            'cfg': 'ini',
            'conf': 'ini',
            'sql': 'sql',
            'md': 'markdown',
            'txt': 'plaintext',
            'env': 'bash'
        };
        if (extensionMap[extension]) {
            return extensionMap[extension];
        }
        // Try to detect from file content patterns
        const content = document.getText();
        return this.detectFromContent(content, fileName);
    }
    detectFromContent(content, fileName) {
        const firstLine = content.split('\n')[0];
        // Check for shebang
        if (firstLine.startsWith('#!')) {
            if (firstLine.includes('python'))
                return 'python';
            if (firstLine.includes('node'))
                return 'javascript';
            if (firstLine.includes('bash') || firstLine.includes('sh'))
                return 'bash';
            if (firstLine.includes('powershell') || firstLine.includes('pwsh'))
                return 'powershell';
        }
        // Check for specific file patterns
        if (fileName.toLowerCase().includes('dockerfile'))
            return 'dockerfile';
        if (fileName.toLowerCase().includes('.env'))
            return 'bash';
        if (fileName.toLowerCase().includes('package.json'))
            return 'json';
        if (fileName.toLowerCase().includes('tsconfig'))
            return 'json';
        // Check content patterns
        if (content.includes('function ') && content.includes('var ') || content.includes('const ')) {
            return 'javascript';
        }
        if (content.includes('def ') && content.includes('import ')) {
            return 'python';
        }
        if (content.includes('<?php')) {
            return 'php';
        }
        if (content.includes('package ') && content.includes('func ')) {
            return 'go';
        }
        return 'plaintext';
    }
    isEnvironmentFile(document) {
        const fileName = document.fileName.toLowerCase();
        const baseName = fileName.split(/[\\/]/).pop() || '';
        return baseName.startsWith('.env') ||
            baseName.endsWith('.env') ||
            baseName.includes('environment') ||
            baseName.includes('config') ||
            this.looksLikeEnvContent(document.getText());
    }
    looksLikeEnvContent(content) {
        const lines = content.split('\n').filter(line => line.trim() && !line.trim().startsWith('#'));
        if (lines.length === 0)
            return false;
        const envPattern = /^[A-Z_][A-Z0-9_]*\s*=\s*.*/;
        const envLines = lines.filter(line => envPattern.test(line.trim()));
        // If more than 50% of non-comment lines look like environment variables
        return envLines.length / lines.length > 0.5;
    }
}
exports.LanguageDetector = LanguageDetector;
//# sourceMappingURL=languageDetector.js.map